@@ -72,6 +72,7 @@ __usage__ = """
 __doc__ %= __usage__
 __usage__ = __doc__.split('\n')[0] + __usage__
 
+from ast import literal_eval
 from collections import deque
 from datetime import date, datetime, timedelta
 import getopt
@@ -683,6 +684,8 @@ def generate_monthly(rain_day_threshold, day_end_hour, use_dst,
         start -= DAY
     del monthly_data[start:]
     stop = daily_data.before(datetime.max)
+    if stop is None:
+        return None
     month_start = start
     acc = MonthAcc(rain_day_threshold)
     count = 0
@@ -715,11 +718,8 @@ def generate_monthly(rain_day_threshold, day_end_hour, use_dst,
 
 def get_day_end_hour(params):
     # get daytime end hour (in local time)
-    day_end_str = params.get('config', 'day end hour', '9, False')
-    if not ',' in day_end_str:
-        day_end_str += ', False'
-        params.set('config', 'day end hour', day_end_str)
-    day_end_hour, use_dst = eval(day_end_str)
+    day_end_hour, use_dst = literal_eval(
+        params.get('config', 'day end hour', '9, False'))
     day_end_hour = day_end_hour % 24
     return day_end_hour, use_dst
 
@@ -741,7 +741,8 @@ def process_data(context):
     # get daytime end hour (in local time)
     day_end_hour, use_dst = get_day_end_hour(context.params)
     # get other config
-    rain_day_threshold = eval(context.params.get('config', 'rain day threshold', '0.2'))
+    rain_day_threshold = float(
+        context.params.get('config', 'rain day threshold', '0.2'))
     # calibrate raw data
     start = calibrate_data(context.params, context.raw_data, context.calib_data)
     # generate hourly data
