@@ -78,6 +78,7 @@ from __future__ import absolute_import
 
 __docformat__ = "restructuredtext en"
 
+from ast import literal_eval
 from datetime import datetime
 import logging
 import sys
@@ -393,9 +394,9 @@ class DriftingClock(object):
         self.period = period
         self.margin = margin
         if self.status:
-            self.clock = eval(
+            self.clock = literal_eval(
                 self.status.get('clock', self.name, 'None'))
-            self.drift = eval(
+            self.drift = literal_eval(
                 self.status.get('clock', self.name + ' drift', '0.0'))
         else:
             self.clock = None
@@ -469,7 +470,7 @@ class WeatherStation(object):
         # init variables
         if context:
             self.status = context.status
-            self.avoid = eval(
+            self.avoid = float(
                 context.params.get('config', 'usb activity margin', '3.0'))
             self.avoid = max(self.avoid, 0.0)
             self.ws_type = context.params.get('config', 'ws type', 'Unknown')
@@ -490,6 +491,7 @@ class WeatherStation(object):
                 'solar', self.status, 60, self.avoid)
         else:
             self._solar_clock = None
+        self.last_status = {}
         # check ws_type
         if self.ws_type not in ('1080', '3080'):
             if self.get_fixed_block(['lux_wm2_coeff']) == 0.0:
@@ -525,7 +527,6 @@ Your station is probably a '{:s}' type.
         next_log = self._station_clock.before(last_log + log_interval)
         ptr_time = 0
         data_time = 0
-        last_status = {}
         not_logging = False
         while True:
             # sleep until just before next reading is due
@@ -560,9 +561,9 @@ Your station is probably a '{:s}' type.
                 for key in ('hum_in', 'temp_in', 'abs_pressure'):
                     old_data[key] = new_data[key]
             # log any change of status
-            if new_data['status'] != last_status:
+            if new_data['status'] != self.last_status:
                 logger.warning('status %s', str(new_data['status']))
-            last_status = new_data['status']
+            self.last_status = new_data['status']
             if (new_data['status']['lost_connection'] and not
                     old_data['status']['lost_connection']):
                 # 'lost connection' decision can happen at any time
@@ -626,17 +627,21 @@ Your station is probably a '{:s}' type.
                             'live_data lost log sync %g', ptr_time - next_log)
                         self._station_clock.invalidate()
                 else:
-                    logger.warning('missed ptr change time')
+                    logger.info('missed ptr change time')
                 if read_period > new_data['delay']:
                     read_period = new_data['delay']
                     logger.warning('reset read period %d', read_period)
                     log_interval = float(read_period * 60)
+                result = dict(new_data)
                 next_log = self._station_clock.before(ptr_time + self.margin)
                 if next_log:
-                    result = dict(new_data)
                     result['idx'] = datetime.utcfromtimestamp(int(next_log))
-                    yield result, old_ptr, True
                     next_log += log_interval
+                else:
+                    # use best guess of logging time
+                    result['idx'] = datetime.utcfromtimestamp(
+                        int(ptr_time - (self.avoid / 2)))
+                yield result, old_ptr, True
                 old_ptr = new_ptr
                 old_data['delay'] = 0
                 data_time = 0
